GILLIAN ANDERSON | TGS - Toulouse Game Show

Aller au contenu principal

# GILLIAN ANDERSON

Gillian ANDERSON, connu pour son rôle de DANA SCULLY, dans la mythique série X-FILES, de Chris CARTER, sera présente au TGS 2015.

Filmographie

Cinéma
Longs métrages

1992 : The Turning de L.A. Puopolo : April Cavanaugh
1997 : Princesse Mononoké (Mononoke-hime) de Hayao Miyazaki : Moro, la déesse louve (voix américaine)
1998 : Chicago Cab (Hellcab) de Mary Cybulski et John Tintori : Brenda
1998 : Les Puissants (The Mighty) de Peter Chelsom : Loretta Lee
1998 : The X Files, le film (The X-Files: Fight the Future) de Rob S. Bowman : Agent spécial Dana Scully
1998 : La Carte du cœur (Playing by Heart) de Willard Carroll : Meredith
2000 : Chez les heureux du monde (The House of Mirth) de Terence Davies : Lily Bart
2005 : The Mighty Celt de Pearse Elliott : Kate Morrison
2005 : Tournage dans un jardin anglais (Tristram Shandy: A Cock and Bull Story) de Michael Winterbottom : Veuve Wadman/Elle-même
2006 : Le Dernier Roi d'Écosse (The Last King of Scotland) de Kevin Macdonald : Sarah Merrit
2007 : Traque sanglante (Straightheads) de Dan Reed : Alice Comfort
2008 : Un Anglais à New York (How to Lose Friends and Alienate People) de Robert B. Weide : Eleanor Johnson
2008 : X-Files : Régénération (The X-Files: I Want to Believe) de Chris Carter : Dana Scully
2010 : Boogie Woogie de Duncan Ward : Jean Maclestone
2011 : Johnny English, le retour (Johnny English Reborn) de Oliver Parker : Agent Pamela Thornton alias Pegasus
2012 : L'Enfant d'en haut (Sister) d'Ursula Meier : Kristin Jansen
2012 : Shadow Dancer de James Marsh : Kate Fletcher
2013 : Mr. Morgan's Last Love de Sandra Nettelbeck : Karen Morgan
2013 : La Colline aux coquelicots (Kokuriko-zaka kara) de Goro Miyazaki : Miki Hokuto (voix américaine)
2014 : I'll Follow You Down de Richie Mehta : Marika Whyte
2015 : The Widowmaker de Patrick Forbes : la narratrice
2015 : Robot Overlords de Jon Wright : Kate Flynn
2015 : Sold de Jeffrey D Brown : Sophia
2016 : Viceroy's House de Gurinder Chadha : Edwina Mountbatten
2016 : Croak de Sam Fell : Mistress

Courts métrages

1986 : Three at Once de Mike Kuhn
1988 : A Matter of Choice de William Davis
2010 : No Pressure de Dougal Wilson
2012 : La Sorcière dans les airs (Room on the Broom) de Jan Lachauer et Max Lang : la sorcière (animation, voix originale)
2014 : The Departure de Gillian Anderson
Télévision[modifier | modifier le code]
Téléfilms[modifier | modifier le code]
2011 : Moby Dick de Mike Barker : Elizabeth Ahab

Séries télévisées

1993 : Promo 96 : Rachel (1 épisode)
1993-2002 : X-Files : Aux frontières du réel : agent spécial Dana Scully
1997 : Les Simpson : Dana Scully (voix originale) (1 épisode)
1999 : Frasier : Jenny (voix) (1 épisode)
1999 : Harsh Realm (1 épisode) : la narratrice (voix)
2005 : Bleak House : Lady Honoria Dedlock (15 épisodes)
2007 : Robbie the Reindeer in Close Encounters of the Herd Kind de Donnie Anderson : Queen Vorkana (voix)
2010 : Any Human Heart : Wallis Simpson, la Duchesse de Windsor (3 épisodes)
2011 : The Crimson Petal and the White : Mme Castaway (2 épisodes)
2011 : De grandes espérances (Great expectations) : Miss Havisham (3 épisodes)
2013-2014 : The Fall de Jakob Verbruggen) : DSI Stella Gibson (11 épisodes)
depuis 2013- : Hannibal : Bedelia Du Maurier (10 épisodes - en cours)
2014 : Crisis : Meg Fitch (10 épisodes)
2014 : Robot Chicken : Fairy Godmother et de Fiona (voix originale) (saison 7, épisode 8 : Up, Up and Buffet)
2016 : War and Peace : Anna Pavlovna Scherer

Scénariste et réalisatrice

2000 : X-Files : Aux frontières du réel créée par Chris Carter (saison 7, épisode 17 : Existences)
2014 : The Departure (réalisatrice)

Gillian ANDERSON sera présente uniquement le SAMEDI 28 NOVEMBRE 2015 et participera à une conférence, ainsi qu'a des sessions de dédicaces et de photoshoot.

Ressources:
CP Gillian ANDERSON.pdf